@@ -673,7 +673,7 @@ struct THREAD_RUN
 #if defined(CONF_FAMILY_UNIX)
 static void *thread_run(void *user)
 #elif defined(CONF_FAMILY_WINDOWS)
-static unsigned int __stdcall thread_run(void *user)
+static unsigned long __stdcall thread_run(void *user)
 #else
 #error not implemented
 #endif
@@ -997,6 +997,14 @@ int net_addr_comp(const NETADDR *a, const NETADDR *b)
 	return mem_comp(a, b, sizeof(NETADDR));
 }
 
+int net_addr_comp_noport(const NETADDR *a, const NETADDR *b)
+{
+	NETADDR ta = *a, tb = *b;
+	ta.port = tb.port = 0;
+
+	return net_addr_comp(&ta, &tb);
+}
+
 void net_addr_str(const NETADDR *addr, char *string, int max_length, int add_port)
 {
 	if(addr->type == NETTYPE_IPV4 || addr->type == NETTYPE_WEBSOCKET_IPV4)
@@ -2179,7 +2187,7 @@ void str_append(char *dst, const char *src, int dst_size)
 
 void str_copy(char *dst, const char *src, int dst_size)
 {
-	strncpy(dst, src, dst_size);
+	strncpy(dst, src, dst_size-1);
 	dst[dst_size-1] = 0; /* assure null termination */
 }
 
@@ -2561,16 +2569,18 @@ static int byteval(const char *byte, unsigned char *dst)
 	return 0;
 }
 
-int str_hex_decode(unsigned char *dst, int dst_size, const char *src)
+int str_hex_decode(void *dst, int dst_size, const char *src)
 {
-	int len = str_length(src)/2;
+	unsigned char *cdst = dst;
+	int slen = str_length(src);
+	int len = slen / 2;
 	int i;
-	if(len != dst_size)
+	if(slen != dst_size * 2)
 		return 2;
 
 	for(i = 0; i < len && dst_size; i++, dst_size--)
 	{
-		if(byteval(src + i * 2, dst++))
+		if(byteval(src + i * 2, cdst++))
 			return 1;
 	}
 	return 0;
