@@ -149,7 +149,7 @@ void mem_zero(void *block, unsigned size);
 		size - Size of the data to compare
 
 	Returns:
-		<0 - Block a is lesser then block b
+		<0 - Block a is lesser than block b
 		0 - Block a is equal to block b
 		>0 - Block a is greater than block b
 */
@@ -666,12 +666,27 @@ int net_host_lookup(const char *hostname, NETADDR *addr, int types);
 		b - Address to compare to.
 
 	Returns:
-		<0 - Address a is lesser then address b
+		<0 - Address a is lesser than address b
 		0 - Address a is equal to address b
-		>0 - Address a is greater then address b
+		>0 - Address a is greater than address b
 */
 int net_addr_comp(const NETADDR *a, const NETADDR *b);
 
+/*
+	Function: net_addr_comp_noport
+		Compares two network addresses ignoring port.
+
+	Parameters:
+		a - Address to compare
+		b - Address to compare to.
+
+	Returns:
+		<0 - Address a is lesser than address b
+		0 - Address a is equal to address b
+		>0 - Address a is greater than address b
+*/
+int net_addr_comp_noport(const NETADDR *a, const NETADDR *b);
+
 /*
 	Function: net_addr_str
 		Turns a network address into a representative string.
@@ -1077,9 +1092,9 @@ char *str_skip_whitespaces(char *str);
 		b - String to compare.
 
 	Returns:
-		<0 - String a is lesser then string b
+		<0 - String a is lesser than string b
 		0 - String a is equal to string b
-		>0 - String a is greater then string b
+		>0 - String a is greater than string b
 
 	Remarks:
 		- Only garanted to work with a-z/A-Z.
@@ -1116,9 +1131,9 @@ int str_comp_nocase_num(const char *a, const char *b, const int num);
 		b - String to compare.
 
 	Returns:
-		<0 - String a is lesser then string b
+		<0 - String a is lesser than string b
 		0 - String a is equal to string b
-		>0 - String a is greater then string b
+		>0 - String a is greater than string b
 
 	Remarks:
 		- The strings are treated as zero-terminated strings.
@@ -1135,9 +1150,9 @@ int str_comp(const char *a, const char *b);
 		num - Maximum characters to compare
 
 	Returns:
-		<0 - String a is lesser then string b
+		<0 - String a is lesser than string b
 		0 - String a is equal to string b
-		>0 - String a is greater then string b
+		>0 - String a is greater than string b
 
 	Remarks:
 		- The strings are treated as zero-terminated strings.
@@ -1153,9 +1168,9 @@ int str_comp_num(const char *a, const char *b, const int num);
 		b - String to compare.
 
 	Returns:
-		<0 - String a is lesser then string b
+		<0 - String a is lesser than string b
 		0 - String a is equal to string b
-		>0 - String a is greater then string b
+		>0 - String a is greater than string b
 
 	Remarks:
 		- The strings are treated as zero-terminated strings.
@@ -1291,7 +1306,8 @@ const char *str_find(const char *haystack, const char *needle);
 
 /*
 	Function: str_hex
-		Takes a datablock and generates a hexstring of it.
+		Takes a datablock and generates a hex string of it, with spaces
+		between bytes.
 
 	Parameters:
 		dst - Buffer to fill with hex data
@@ -1306,7 +1322,8 @@ void str_hex(char *dst, int dst_size, const void *data, int data_size);
 
 /*
 	Function: str_hex_decode
-		Takes a hex string and returns a byte array.
+		Takes a hex string *without spaces between bytes* and returns a
+		byte array.
 
 	Parameters:
 		dst - Buffer for the byte array
@@ -1321,7 +1338,7 @@ void str_hex(char *dst, int dst_size, const void *data, int data_size);
 	Remarks:
 		- The contents of the buffer is only valid on success
 */
-int str_hex_decode(unsigned char *dst, int dst_size, const char *src);
+int str_hex_decode(void *dst, int dst_size, const char *src);
 /*
 	Function: str_timestamp
 		Copies a time stamp in the format year-month-day_hour-minute-second to the string.
