@@ -554,6 +554,51 @@ int CServer::MaxClients() const
 	return m_NetServer.MaxClients();
 }
 
+int CServer::ClientCount()
+{
+	int ClientCount = 0;
+	for(int i = 0; i < MAX_CLIENTS; i++)
+	{
+		if(m_aClients[i].m_State != CClient::STATE_EMPTY)
+		{
+			ClientCount++;
+		}
+	}
+
+	return ClientCount;
+}
+
+int CServer::DistinctClientCount()
+{
+	NETADDR aAddresses[MAX_CLIENTS];
+	for(int i = 0; i < MAX_CLIENTS; i++)
+	{
+		if(m_aClients[i].m_State != CClient::STATE_EMPTY)
+		{
+			GetClientAddr(i, &aAddresses[i]);
+		}
+	}
+
+	int ClientCount = 0;
+	for(int i = 0; i < MAX_CLIENTS; i++)
+	{
+		if(m_aClients[i].m_State != CClient::STATE_EMPTY)
+		{
+			ClientCount++;
+			for(int j = 0; j < i; j++)
+			{
+				if(!net_addr_comp_noport(&aAddresses[i], &aAddresses[j]))
+				{
+					ClientCount--;
+					break;
+				}
+			}
+		}
+	}
+
+	return ClientCount;
+}
+
 int CServer::SendMsg(CMsgPacker *pMsg, int Flags, int ClientID)
 {
 	return SendMsgEx(pMsg, Flags, ClientID, false);
@@ -842,6 +887,7 @@ void CServer::InitDnsbl(int ClientID)
 
 	IEngine *pEngine = Kernel()->RequestInterface<IEngine>();
 	pEngine->AddJob(m_aClients[ClientID].m_pDnsblLookup = std::make_shared<CHostLookup>(aBuf, NETTYPE_IPV4));
+	m_aClients[ClientID].m_DnsblState = CClient::DNSBL_STATE_PENDING;
 }
 
 #ifdef CONF_FAMILY_UNIX
@@ -1876,7 +1922,6 @@ int CServer::Run()
 					if (m_aClients[ClientID].m_DnsblState == CClient::DNSBL_STATE_NONE)
 					{
 						// initiate dnsbl lookup
-						m_aClients[ClientID].m_DnsblState = CClient::DNSBL_STATE_PENDING;
 						InitDnsbl(ClientID);
 					}
 					else if (m_aClients[ClientID].m_DnsblState == CClient::DNSBL_STATE_PENDING &&
@@ -1900,7 +1945,7 @@ int CServer::Run()
 							char aBuf[256];
 
 							str_format(aBuf, sizeof(aBuf), "ClientID=%d addr=%s secure=%s blacklisted", ClientID, aAddrStr, m_NetServer.HasSecurityToken(ClientID)?"yes":"no");
-							
+
 							Console()->Print(IConsole::OUTPUT_LEVEL_ADDINFO, "dnsbl", aBuf);
 						}
 					}
@@ -2341,7 +2386,7 @@ void CServer::ConNameBan(IConsole::IResult *pResult, void *pUser)
 	{
 		Distance = str_length(pName) / 3;
 	}
-	
+
 	for(int i = 0; i < pThis->m_aNameBans.size(); i++)
 	{
 		CNameBan *pBan = &pThis->m_aNameBans[i];
@@ -2529,7 +2574,7 @@ void CServer::ConAddSqlServer(IConsole::IResult *pResult, void *pUserData)
 	{
 		if (!apSqlServers[i])
 		{
-			apSqlServers[i] = new CSqlServer(pResult->GetString(1), pResult->GetString(2), pResult->GetString(3), pResult->GetString(4), pResult->GetString(5), pResult->GetInteger(6), ReadOnly, SetUpDb);
+			apSqlServers[i] = new CSqlServer(pResult->GetString(1), pResult->GetString(2), pResult->GetString(3), pResult->GetString(4), pResult->GetString(5), pResult->GetInteger(6), &pSelf->m_GlobalSqlLock, ReadOnly, SetUpDb);
 
 			if(SetUpDb)
 			{
@@ -2859,7 +2904,7 @@ int main(int argc, const char **argv) // ignore_convention
 	IKernel *pKernel = IKernel::Create();
 
 	// create the components
-	IEngine *pEngine = CreateEngine("DDNet", Silent);
+	IEngine *pEngine = CreateEngine("DDNet", Silent, 2);
 	IEngineMap *pEngineMap = CreateEngineMap();
 	IGameServer *pGameServer = CreateGameServer();
 	IConsole *pConsole = CreateConsole(CFGFLAG_SERVER|CFGFLAG_ECON);
