@@ -185,12 +185,15 @@ const CSkins::CSkin *CSkins::Get(int Index)
 
 int CSkins::Find(const char *pName) const
 {
-	if(g_Config.m_ClSkinPrefix[0])
+	if(g_Config.m_ClVanillaSkinsOnly && !IsVanillaSkin(pName))
+	{
+		return -1;
+	}
+	else if(g_Config.m_ClSkinPrefix[0])
 	{
 		char aBuf[64];
 		str_format(aBuf, sizeof(aBuf), "%s_%s", g_Config.m_ClSkinPrefix, pName);
-		// If we find something, use it, otherwise fall back to normal
-		// skins.
+		// If we find something, use it, otherwise fall back to normal skins.
 		int Result = FindImpl(aBuf);
 		if(Result != -1)
 		{
@@ -198,7 +201,6 @@ int CSkins::Find(const char *pName) const
 		}
 	}
 	return FindImpl(pName);
-
 }
 
 int CSkins::FindImpl(const char *pName) const
@@ -207,14 +209,7 @@ int CSkins::FindImpl(const char *pName) const
 	{
 		if(str_comp(m_aSkins[i].m_aName, pName) == 0)
 		{
-			if(g_Config.m_ClVanillaSkinsOnly && !m_aSkins[i].m_IsVanilla)
-			{
-				return -1;
-			}
-			else
-			{
-				return i;
-			}
+			return i;
 		}
 	}
 	return -1;
