@@ -1,4 +1,5 @@
 #include <stdio.h>	// sscanf
+#include <inttypes.h>
 
 #include <engine/console.h>
 #include <engine/storage.h>
@@ -7,6 +8,35 @@
 #include "auto_map.h"
 #include "editor.h"
 
+// Based on triple32inc from https://github.com/skeeto/hash-prospector/tree/79a6074062a84907df6e45b756134b74e2956760
+static uint32_t HashUInt32(uint32_t Num)
+{
+	Num++;
+	Num ^= Num >> 17;
+	Num *= 0xed5ad4bbu;
+	Num ^= Num >> 11;
+	Num *= 0xac4c1b51u;
+	Num ^= Num >> 15;
+	Num *= 0x31848babu;
+	Num ^= Num >> 14;
+	return Num;
+}
+
+#define HASH_MAX 65536
+
+static int HashLocation(uint32_t Seed, uint32_t Run, uint32_t Rule, uint32_t X, uint32_t Y)
+{
+	const uint32_t Prime = 31;
+	uint32_t Hash = 1;
+	Hash = Hash * Prime + HashUInt32(Seed);
+	Hash = Hash * Prime + HashUInt32(Run);
+	Hash = Hash * Prime + HashUInt32(Rule);
+	Hash = Hash * Prime + HashUInt32(X);
+	Hash = Hash * Prime + HashUInt32(Y);
+	Hash = HashUInt32(Hash * Prime); // Just to double-check that values are well-distributed
+	return Hash % HASH_MAX;
+}
+
 CAutoMapper::CAutoMapper(CEditor *pEditor)
 {
 	m_pEditor = pEditor;
@@ -42,6 +72,10 @@ void CAutoMapper::Load(const char* pTileName)
 				// new configuration, get the name
 				pLine++;
 				CConfiguration NewConf;
+				NewConf.m_StartX = 0;
+				NewConf.m_StartY = 0;
+				NewConf.m_EndX = 0;
+				NewConf.m_EndY = 0;
 				int ConfigurationID = m_lConfigs.add(NewConf);
 				pCurrentConf = &m_lConfigs[ConfigurationID];
 				str_copy(pCurrentConf->m_aName, pLine, str_length(pLine));
@@ -75,6 +109,8 @@ void CAutoMapper::Load(const char* pTileName)
 				NewIndexRule.m_Flag = 0;
 				NewIndexRule.m_RandomProbability = 1.0;
 				NewIndexRule.m_DefaultRule = true;
+				NewIndexRule.m_SkipEmpty = false;
+				NewIndexRule.m_SkipFull = false;
 
 				if(str_length(aOrientation1) > 0)
 				{
@@ -122,13 +158,13 @@ void CAutoMapper::Load(const char* pTileName)
 				if(!str_comp(aValue, "EMPTY"))
 				{
 					Value = CPosRule::INDEX;
-					CIndexInfo NewIndexInfo = {0, 0};
+					CIndexInfo NewIndexInfo = {0, 0, false};
 					NewIndexList.add(NewIndexInfo);
 				}
 				else if(!str_comp(aValue, "FULL"))
 				{
 					Value = CPosRule::NOTINDEX;
-					CIndexInfo NewIndexInfo1 = {0, 0};
+					CIndexInfo NewIndexInfo1 = {0, 0, false};
 					//CIndexInfo NewIndexInfo2 = {-1, 0};
 					NewIndexList.add(NewIndexInfo1);
 					//NewIndexList.add(NewIndexInfo2);
@@ -151,13 +187,15 @@ void CAutoMapper::Load(const char* pTileName)
 
 						CIndexInfo NewIndexInfo;
 						NewIndexInfo.m_ID = ID;
-						NewIndexInfo.m_Flag = -1;
+						NewIndexInfo.m_Flag = 0;
+						NewIndexInfo.m_TestFlag = false;
 
 						if(!str_comp(aOrientation1, "OR")) {
 							NewIndexList.add(NewIndexInfo);
 							pWord += 2;
 							continue;
 						} else if(str_length(aOrientation1) > 0) {
+							NewIndexInfo.m_TestFlag = true;
 							if(!str_comp(aOrientation1, "XFLIP"))
 								NewIndexInfo.m_Flag = TILEFLAG_VFLIP;
 							else if(!str_comp(aOrientation1, "YFLIP"))
@@ -166,6 +204,8 @@ void CAutoMapper::Load(const char* pTileName)
 								NewIndexInfo.m_Flag = TILEFLAG_ROTATE;
 							else if(!str_comp(aOrientation1, "NONE"))
 								NewIndexInfo.m_Flag = 0;
+							else
+								NewIndexInfo.m_TestFlag = false;
 						} else {
 							NewIndexList.add(NewIndexInfo);
 							break;
@@ -217,6 +257,21 @@ void CAutoMapper::Load(const char* pTileName)
 				if(Value != CPosRule::NORULE) {
 					CPosRule NewPosRule = {x, y, Value, NewIndexList};
 					pCurrentIndex->m_aRules.add(NewPosRule);
+
+					pCurrentConf->m_StartX = min(pCurrentConf->m_StartX, NewPosRule.m_X);
+					pCurrentConf->m_StartY = min(pCurrentConf->m_StartY, NewPosRule.m_Y);
+					pCurrentConf->m_EndX = max(pCurrentConf->m_EndX, NewPosRule.m_X);
+					pCurrentConf->m_EndY = max(pCurrentConf->m_EndY, NewPosRule.m_Y);
+
+					if(x == 0 && y == 0) {
+						for(int i = 0; i < NewIndexList.size(); ++i) 
+						{
+							if(Value == CPosRule::INDEX && NewIndexList[i].m_ID == 0)
+								pCurrentIndex->m_SkipFull = true;
+							else
+								pCurrentIndex->m_SkipEmpty = true;
+						}
+					}
 				}
 			}
 			else if(str_startswith(pLine, "Random") && pCurrentIndex)
@@ -251,23 +306,31 @@ void CAutoMapper::Load(const char* pTileName)
 		{
 			for(int i = 0; i < m_lConfigs[g].m_aRuns[h].m_aIndexRules.size(); ++i)
 			{
+				CIndexRule *pIndexRule = &m_lConfigs[g].m_aRuns[h].m_aIndexRules[i];
 				bool Found = false;
-				for(int j = 0; j < m_lConfigs[g].m_aRuns[h].m_aIndexRules[i].m_aRules.size(); ++j)
+				for(int j = 0; j < pIndexRule->m_aRules.size(); ++j)
 				{
-					CPosRule *pRule = &m_lConfigs[g].m_aRuns[h].m_aIndexRules[i].m_aRules[j];
+					CPosRule *pRule = &pIndexRule->m_aRules[j];
 					if(pRule && pRule->m_X == 0 && pRule->m_Y == 0)
 					{
 						Found = true;
 						break;
 					}
 				}
-				if(!Found && m_lConfigs[g].m_aRuns[h].m_aIndexRules[i].m_DefaultRule)
+				if(!Found && pIndexRule->m_DefaultRule)
 				{
 					array<CIndexInfo> NewIndexList;
-					CIndexInfo NewIndexInfo = {0, 0};
+					CIndexInfo NewIndexInfo = {0, 0, false};
 					NewIndexList.add(NewIndexInfo);
 					CPosRule NewPosRule = {0, 0, CPosRule::NOTINDEX, NewIndexList};
-					m_lConfigs[g].m_aRuns[h].m_aIndexRules[i].m_aRules.add(NewPosRule);
+					pIndexRule->m_aRules.add(NewPosRule);
+					
+					pIndexRule->m_SkipEmpty = true;
+					pIndexRule->m_SkipFull = false;
+				}
+				if(pIndexRule->m_SkipEmpty && pIndexRule->m_SkipFull)
+				{
+					pIndexRule->m_SkipFull = false;
 				}
 			}
 		}
@@ -289,11 +352,70 @@ const char* CAutoMapper::GetConfigName(int Index)
 	return m_lConfigs[Index].m_aName;
 }
 
-void CAutoMapper::Proceed(CLayerTiles *pLayer, int ConfigID)
+void CAutoMapper::ProceedLocalized(CLayerTiles *pLayer, int ConfigID, int Seed, int X, int Y, int Width, int Height)
 {
 	if(!m_FileLoaded || pLayer->m_Readonly || ConfigID < 0 || ConfigID >= m_lConfigs.size())
 		return;
 
+	if(Width < 0)
+		Width = pLayer->m_Width;
+
+	if(Height < 0)
+		Height = pLayer->m_Height;
+
+	CConfiguration *pConf = &m_lConfigs[ConfigID];
+
+	int CommitFromX = max(X + pConf->m_StartX, 0);
+	int CommitFromY = max(Y + pConf->m_StartY, 0);
+	int CommitToX = min(X + Width + pConf->m_EndX, pLayer->m_Width);
+	int CommitToY = min(Y + Height + pConf->m_EndY, pLayer->m_Height);
+
+	int UpdateFromX = max(X + 3 * pConf->m_StartX, 0);
+	int UpdateFromY = max(Y + 3 * pConf->m_StartY, 0);
+	int UpdateToX = min(X + Width + 3 * pConf->m_EndX, pLayer->m_Width);
+	int UpdateToY = min(Y + Height + 3 * pConf->m_EndY, pLayer->m_Height);
+
+	CLayerTiles *pUpdateLayer;
+	if (UpdateFromX != 0 || UpdateFromY != 0 || UpdateToX != pLayer->m_Width || UpdateToY != pLayer->m_Width)
+	{ // Needs a layer to work on
+		pUpdateLayer = new CLayerTiles(UpdateToX - UpdateFromX, UpdateToY - UpdateFromY);
+
+		for(int y = UpdateFromY; y < UpdateToY; y++) {
+			for(int x = UpdateFromX; x < UpdateToX; x++)
+			{
+				CTile *in = &pLayer->m_pTiles[y*pLayer->m_Width+x];
+				CTile *out = &pUpdateLayer->m_pTiles[(y-UpdateFromY)*pUpdateLayer->m_Width+x-UpdateFromX];
+				out->m_Index = in->m_Index;
+				out->m_Flags = in->m_Flags;
+			}
+		}
+	}
+	else
+	{
+		pUpdateLayer = pLayer;
+	}
+
+	Proceed(pUpdateLayer, ConfigID, Seed, UpdateFromX, UpdateFromY);
+
+	for(int y = CommitFromY; y < CommitToY; y++) {
+		for(int x = CommitFromX; x < CommitToX; x++)
+		{
+			CTile *in = &pUpdateLayer->m_pTiles[(y-UpdateFromY)*pUpdateLayer->m_Width+x-UpdateFromX];
+			CTile *out = &pLayer->m_pTiles[y*pLayer->m_Width+x];
+			out->m_Index = in->m_Index;
+			out->m_Flags = in->m_Flags;
+		}
+	}
+}
+
+void CAutoMapper::Proceed(CLayerTiles *pLayer, int ConfigID, int Seed, int SeedOffsetX, int SeedOffsetY)
+{
+	if(!m_FileLoaded || pLayer->m_Readonly || ConfigID < 0 || ConfigID >= m_lConfigs.size())
+		return;
+
+	if(Seed == 0)
+		Seed = rand();
+
 	CConfiguration *pConf = &m_lConfigs[ConfigID];
 
 	// for every run: copy tiles, automap, overwrite tiles
@@ -302,18 +424,10 @@ void CAutoMapper::Proceed(CLayerTiles *pLayer, int ConfigID)
 
 		// don't make copy if it's requested
 		CLayerTiles *pReadLayer;
-		if(pRun->m_AutomapCopy) 
+		if(pRun->m_AutomapCopy)
 		{
 			pReadLayer = new CLayerTiles(pLayer->m_Width, pLayer->m_Height);
-		} 
-		else 
-		{
-			pReadLayer = pLayer;
-		}
 
-		// copy tiles
-		if(pRun->m_AutomapCopy) 
-		{
 			for(int y = 0; y < pLayer->m_Height; y++) {
 				for(int x = 0; x < pLayer->m_Width; x++)
 				{
@@ -324,6 +438,10 @@ void CAutoMapper::Proceed(CLayerTiles *pLayer, int ConfigID)
 				}
 			}
 		}
+		else
+		{
+			pReadLayer = pLayer;
+		}
 
 		// auto map
 		for(int y = 0; y < pLayer->m_Height; y++) {
@@ -334,10 +452,16 @@ void CAutoMapper::Proceed(CLayerTiles *pLayer, int ConfigID)
 
 				for(int i = 0; i < pRun->m_aIndexRules.size(); ++i)
 				{
+					CIndexRule *pIndexRule = &pRun->m_aIndexRules[i];
+					if(pIndexRule->m_SkipEmpty && pTile->m_Index == 0) // skip empty tiles
+						continue;
+					if(pIndexRule->m_SkipFull && pTile->m_Index != 0) // skip full tiles
+						continue;
+
 					bool RespectRules = true;
-					for(int j = 0; j < pRun->m_aIndexRules[i].m_aRules.size() && RespectRules; ++j)
+					for(int j = 0; j < pIndexRule->m_aRules.size() && RespectRules; ++j)
 					{
-						CPosRule *pRule = &pRun->m_aIndexRules[i].m_aRules[j];
+						CPosRule *pRule = &pIndexRule->m_aRules[j];
 
 						int CheckIndex, CheckFlags;
 						int CheckX = x + pRule->m_X;
@@ -355,7 +479,7 @@ void CAutoMapper::Proceed(CLayerTiles *pLayer, int ConfigID)
 						{
 							RespectRules = false;
 							for(int i = 0; i < pRule->m_aIndexList.size(); ++i) {
-								if(CheckIndex == pRule->m_aIndexList[i].m_ID && (pRule->m_aIndexList[i].m_Flag == -1 || CheckFlags == pRule->m_aIndexList[i].m_Flag))
+								if(CheckIndex == pRule->m_aIndexList[i].m_ID && (!pRule->m_aIndexList[i].m_TestFlag || CheckFlags == pRule->m_aIndexList[i].m_Flag))
 								{
 									RespectRules = true;
 									break;
@@ -365,7 +489,7 @@ void CAutoMapper::Proceed(CLayerTiles *pLayer, int ConfigID)
 	 					else if(pRule->m_Value == CPosRule::NOTINDEX)
 						{
 							for(int i = 0; i < pRule->m_aIndexList.size(); ++i) {
-								if(CheckIndex == pRule->m_aIndexList[i].m_ID && (pRule->m_aIndexList[i].m_Flag == -1 || CheckFlags == pRule->m_aIndexList[i].m_Flag))
+								if(CheckIndex == pRule->m_aIndexList[i].m_ID && (!pRule->m_aIndexList[i].m_TestFlag || CheckFlags == pRule->m_aIndexList[i].m_Flag))
 								{
 									RespectRules = false;
 									break;
@@ -375,10 +499,10 @@ void CAutoMapper::Proceed(CLayerTiles *pLayer, int ConfigID)
 					}
 
 					if(RespectRules &&
-						(pRun->m_aIndexRules[i].m_RandomProbability >= 1.0 || (float)rand() / ((float)RAND_MAX + 1) < pRun->m_aIndexRules[i].m_RandomProbability))
+						(pIndexRule->m_RandomProbability >= 1.0 || HashLocation(Seed, h, i, x + SeedOffsetX, y + SeedOffsetY) < HASH_MAX * pIndexRule->m_RandomProbability))
 					{
-						pTile->m_Index = pRun->m_aIndexRules[i].m_ID;
-						pTile->m_Flags = pRun->m_aIndexRules[i].m_Flag;
+						pTile->m_Index = pIndexRule->m_ID;
+						pTile->m_Flags = pIndexRule->m_Flag;
 					}
 				}
 			}
